@@ -1,5 +1,6 @@
 #include "TlsServer.hxx"
 #include <boost/bind.hpp>
+#include <rutil/Data.hxx>
 #include <rutil/WinLeakCheck.hxx>
 #include <rutil/Logger.hxx>
 #include "ReTurnSubsystem.hxx"
@@ -28,13 +29,20 @@ TlsServer::TlsServer(asio::io_service& ioService, RequestHandler& requestHandler
    if(ec)
    {
       ErrLog(<< "Unable to load server cert chain file: " << mRequestHandler.getConfig().mTlsServerCertificateFilename << ", error=" << ec.value() << "(" << ec.message() << ")");
+      throw asio::system_error(ec);
    }
 
    // Use a private key from a file.
-   mContext.use_private_key_file(mRequestHandler.getConfig().mTlsServerCertificateFilename.c_str(), asio::ssl::context::pem, ec);
+   resip::Data keyFilename = mRequestHandler.getConfig().mTlsServerPrivateKeyFilename;
+   if(keyFilename.empty())
+   {
+      keyFilename = mRequestHandler.getConfig().mTlsServerCertificateFilename;
+   }
+   mContext.use_private_key_file(keyFilename.c_str(), asio::ssl::context::pem, ec);
    if(ec)
    {
-      ErrLog(<< "Unable to load server private key file: " << mRequestHandler.getConfig().mTlsServerCertificateFilename << ", error=" << ec.value() << "(" << ec.message() << ")");
+      ErrLog(<< "Unable to load server private key file: " << keyFilename << ", error=" << ec.value() << "(" << ec.message() << ")");
+      throw asio::system_error(ec);
    }
 
    // Use the specified file to obtain the temporary Diffie-Hellman parameters.
@@ -42,6 +50,7 @@ TlsServer::TlsServer(asio::io_service& ioService, RequestHandler& requestHandler
    if(ec)
    {
       ErrLog(<< "Unable to load temporary Diffie-Hellman parameters file: " << mRequestHandler.getConfig().mTlsTempDhFilename << ", error=" << ec.value() << "(" << ec.message() << ")");
+      throw asio::system_error(ec);
    }
 
    // Open the acceptor with the option to reuse the address (i.e. SO_REUSEADDR).
@@ -90,6 +99,12 @@ TlsServer::handleAccept(const asio::error_code& e)
    else
    {
       ErrLog(<< "Error in handleAccept: " << e.value() << "-" << e.message());
+      if(e == asio::error::no_descriptors)
+      {
+         // Retry if too many open files (ie. out of socket descriptors)
+         mNewConnection.reset(new TlsConnection(mIOService, mConnectionManager, mRequestHandler, mContext));
+         mAcceptor.async_accept(((TlsConnection*)mNewConnection.get())->socket(), boost::bind(&TlsServer::handleAccept, this, asio::placeholders::error));
+      }
    }
 }
 
