@@ -1,4 +1,4 @@
-#include <cassert>
+#include "rutil/ResipAssert.h"
 #include <fcntl.h>
 
 #ifdef HAVE_CONFIG_H
@@ -76,8 +76,7 @@ MySqlDb::MySqlDb(const Data& server,
    mDBName(databaseName),
    mDBPort(port),
    mCustomUserAuthQuery(customUserAuthQuery),
-   mConn(0),
-   mConnected(false)
+   mConn(0)
 { 
    InfoLog( << "Using MySQL DB with server=" << server << ", user=" << user << ", dbName=" << databaseName << ", port=" << port);
 
@@ -129,7 +128,7 @@ MySqlDb::disconnectFromDatabase() const
    
       mysql_close(mConn);
       mConn = 0;
-      mConnected = false;
+      setConnected(false);
    }
 }
 
@@ -140,8 +139,8 @@ MySqlDb::connectToDatabase() const
    disconnectFromDatabase();
 
    // Now try to connect
-   assert(mConn == 0);
-   assert(mConnected == false);
+   resip_assert(mConn == 0);
+   resip_assert(isConnected() == false);
 
    mConn = mysql_init(0);
    if(mConn == 0)
@@ -165,12 +164,12 @@ MySqlDb::connectToDatabase() const
       ErrLog( << "MySQL connect failed: error=" << rc << ": " << mysql_error(mConn));
       mysql_close(mConn); 
       mConn = 0;
-      mConnected = false;
+      setConnected(false);
       return rc;
    }
    else
    {
-      mConnected = true;
+      setConnected(true);
       return 0;
    }
 }
@@ -185,14 +184,14 @@ MySqlDb::query(const Data& queryCommand, MYSQL_RES** result) const
    DebugLog( << "MySqlDb::query: executing query: " << queryCommand);
 
    Lock lock(mMutex);
-   if(mConn == 0 || !mConnected)
+   if(mConn == 0 || !isConnected())
    {
       rc = connectToDatabase();
    }
    if(rc == 0)
    {
-      assert(mConn!=0);
-      assert(mConnected);
+      resip_assert(mConn!=0);
+      resip_assert(isConnected());
       rc = mysql_query(mConn,queryCommand.c_str());
       if(rc != 0)
       {
@@ -240,6 +239,12 @@ MySqlDb::query(const Data& queryCommand, MYSQL_RES** result) const
    return rc;
 }
 
+int
+MySqlDb::query(const Data& queryCommand) const
+{
+   return query(queryCommand, 0);
+}
+
 int
 MySqlDb::singleResultQuery(const Data& queryCommand, std::vector<Data>& fields) const
 {
@@ -312,19 +317,6 @@ MySqlDb::addUser(const AbstractDb::Key& key, const AbstractDb::UserRecord& rec)
 }
 
 
-void 
-MySqlDb::eraseUser(const AbstractDb::Key& key )
-{ 
-   Data command;
-   {
-      DataStream ds(command);
-      ds << "DELETE FROM users ";
-      userWhereClauseToDataStream(key, ds);
-   }
-   query(command, 0);
-}
-
-
 AbstractDb::UserRecord 
 MySqlDb::getUser( const AbstractDb::Key& key ) const
 {
@@ -527,29 +519,6 @@ MySqlDb::dbReadRecord(const Table table,
 }
 
 
-void 
-MySqlDb::dbEraseRecord(const Table table, 
-                       const resip::Data& pKey,
-                       bool isSecondaryKey) // allows deleting records from a table that supports secondary keying using a secondary key
-{ 
-   Data command;
-   {
-      DataStream ds(command);
-      Data escapedKey;
-      ds << "DELETE FROM " << tableName(table);
-      if(isSecondaryKey)
-      {
-         ds << " WHERE attr2='" << escapeString(pKey, escapedKey) << "'";
-      }
-      else
-      {
-         ds << " WHERE attr='" << escapeString(pKey, escapedKey) << "'";
-      }
-   }   
-   query(command, 0);
-}
-
-
 resip::Data 
 MySqlDb::dbNextKey(const Table table, bool first)
 { 
@@ -674,54 +643,6 @@ MySqlDb::dbBeginTransaction(const Table table)
    return false;
 }
 
-bool 
-MySqlDb::dbCommitTransaction(const Table table)
-{
-   Data command("COMMIT");
-   return query(command, 0) == 0;
-}
-
-bool 
-MySqlDb::dbRollbackTransaction(const Table table)
-{
-   Data command("ROLLBACK");
-   return query(command, 0) == 0;
-}
-
-static const char usersavp[] = "usersavp";
-static const char routesavp[] = "routesavp";
-static const char aclsavp[] = "aclsavp";
-static const char configsavp[] = "configsavp";
-static const char staticregsavp[] = "staticregsavp";
-static const char filtersavp[] = "filtersavp";
-static const char siloavp[] = "siloavp";
-
-const char*
-MySqlDb::tableName(Table table) const
-{
-   switch (table)
-   {
-      case UserTable:
-         assert(false);  // usersavp is not used!
-         return usersavp;
-      case RouteTable:
-         return routesavp;
-      case AclTable:
-         return aclsavp; 
-      case ConfigTable:
-         return configsavp;
-      case StaticRegTable:
-         return staticregsavp;
-      case FilterTable:
-         return filtersavp;
-      case SiloTable:
-         return siloavp;
-      default:
-         assert(0);
-   }
-   return 0;
-}
-
 void 
 MySqlDb::userWhereClauseToDataStream(const Key& key, DataStream& ds) const
 {
@@ -733,18 +654,6 @@ MySqlDb::userWhereClauseToDataStream(const Key& key, DataStream& ds) const
       << "'";      
 }
    
-void
-MySqlDb::getUserAndDomainFromKey(const Key& key, Data& user, Data& domain) const
-{
-   ParseBuffer pb(key);
-   const char* start = pb.position();
-   pb.skipToOneOf("@");
-   pb.data(user, start);
-   const char* anchor = pb.skipChar();
-   pb.skipToEnd();
-   pb.data(domain, anchor);
-}
-
 #endif // USE_MYSQL
 
 /* ====================================================================
