@@ -14,6 +14,7 @@
 #include "resip/stack/Helper.hxx"
 #include "resip/stack/InteropHelper.hxx"
 #include "rutil/Random.hxx"
+#include "rutil/Lock.hxx"
 #include "rutil/Logger.hxx"
 #include "rutil/Inserter.hxx"
 #include "rutil/WinLeakCheck.hxx"
@@ -83,6 +84,7 @@ Proxy::Proxy(SipStack& stack,
      mRecordRouteForced(config.getConfigBool("ForceRecordRouting", false)),
      mAssumePath(config.getConfigBool("AssumePath", false)),
      mPAssertedIdentityProcessing(config.getConfigBool("EnablePAssertedIdentityProcessing", false)),
+     mNeverStripProxyAuthorizationHeaders(config.getConfigBool("NeverStripProxyAuthorizationHeaders", false)),
 #ifdef PACKAGE_VERSION
      mServerText(config.getConfigData("ServerText", "repro " PACKAGE_VERSION)),
 #else
@@ -116,7 +118,6 @@ Proxy::Proxy(SipStack& stack,
    }
 }
 
-
 Proxy::~Proxy()
 {
    shutdown();
@@ -143,14 +144,12 @@ Proxy::isShutDown() const
   return false;
 }
 
-
 UserStore&
 Proxy::getUserStore()
 {
    return mUserStore;
 }
 
-
 void
 Proxy::thread()
 {
@@ -557,14 +556,12 @@ Proxy::postTimerC(std::auto_ptr<TimerCMessage> tc)
    }
 }
 
-
 void
 Proxy::postMS(std::auto_ptr<resip::ApplicationMessage> msg, int msec)
 {
    mStack.postMS(*msg,msec,this);
 }
 
-
 const Data& 
 Proxy::name() const
 {
@@ -599,22 +596,30 @@ Proxy::isMyUri(const Uri& uri) const
    return ret;
 }
 
-const resip::NameAddr& 
-Proxy::getRecordRoute(const Transport* transport) const
+void 
+Proxy::addTransportRecordRoute(unsigned int transportKey, const resip::NameAddr& recordRoute)
 {
-   assert(transport);
-   if(transport->hasRecordRoute())
-   {
-      // Transport specific record-route found
-      return transport->getRecordRoute();
-   }
-   return mRecordRoute;
+   Lock lock(mTransportRecordRouteMutex);
+   mTransportRecordRoutes[transportKey] = recordRoute;
 }
 
-bool
-Proxy::getRecordRouteForced() const
+void Proxy::removeTransportRecordRoute(unsigned int transportKey)
 {
-   return mRecordRouteForced;
+   Lock lock(mTransportRecordRouteMutex);
+   mTransportRecordRoutes.erase(transportKey);
+}
+
+const resip::NameAddr& 
+Proxy::getRecordRoute(unsigned int transportKey) const
+{
+   Lock lock(mTransportRecordRouteMutex);
+   TransportRecordRouteMap::const_iterator it = mTransportRecordRoutes.find(transportKey);
+   if(it != mTransportRecordRoutes.end())
+   {
+      // Transport specific record-route found
+      return it->second;
+   }
+   return mRecordRoute;
 }
 
 bool 
@@ -640,7 +645,7 @@ Proxy::doSessionAccounting(const resip::SipMessage& sip, bool received, RequestC
 {
    if(mSessionAccountingEnabled)
    {
-      assert(mAccountingCollector);
+      resip_assert(mAccountingCollector);
       mAccountingCollector->doSessionAccounting(sip, received, context);
    }
 }
@@ -650,7 +655,7 @@ Proxy::doRegistrationAccounting(AccountingCollector::RegistrationEvent regEvent,
 {
    if(mRegistrationAccountingEnabled)
    {
-      assert(mAccountingCollector);
+      resip_assert(mAccountingCollector);
       mAccountingCollector->doRegistrationAccounting(regEvent, sip);
    }
 }
