@@ -15,6 +15,7 @@
 #include "resip/dum/ServerSubscription.hxx"
 #include "resip/dum/SubscriptionHandler.hxx"
 #include "resip/dum/UsageUseException.hxx"
+#include "rutil/ResipAssert.h"
 #include "rutil/Logger.hxx"
 #include "rutil/Inserter.hxx"
 #include "rutil/TransportType.hxx"
@@ -41,16 +42,15 @@ Dialog::Dialog(DialogUsageManager& dum, const SipMessage& msg, DialogSet& ds)
      mLocalNameAddr(),
      mRemoteNameAddr(),
      mCallId(msg.header(h_CallID)),
-     mDefaultSubExpiration(0),
      mAppDialog(0),
      mDestroying(false),
      mReUseDialogSet(false)
 {
-   assert(msg.isExternal());
+   resip_assert(msg.isExternal());
 
-   assert(msg.header(h_CSeq).method() != MESSAGE);
-   assert(msg.header(h_CSeq).method() != REGISTER);
-   assert(msg.header(h_CSeq).method() != PUBLISH);
+   resip_assert(msg.header(h_CSeq).method() != MESSAGE);
+   resip_assert(msg.header(h_CSeq).method() != REGISTER);
+   resip_assert(msg.header(h_CSeq).method() != PUBLISH);
 
    mNetworkAssociation.setDum(&dum);
 
@@ -338,9 +338,9 @@ Dialog::getRouteSet() const
 void
 Dialog::cancel()
 {
-   assert(mType == Invitation);
+   resip_assert(mType == Invitation);
    ClientInviteSession* uac = dynamic_cast<ClientInviteSession*>(mInviteSession);
-   assert (uac);
+   resip_assert (uac);
    uac->cancel();
 }
 
@@ -379,6 +379,8 @@ Dialog::handleTargetRefresh(const SipMessage& msg)
    {
       case INVITE:
       case UPDATE:
+      case SUBSCRIBE: // RFC6665 - Note: target refreshes via NOTIFY requests are handled via 
+                      //           ClientSubscription usage after NOTIFY ordering is confirmed
          if (msg.isRequest() || (msg.isResponse() && msg.header(h_StatusLine).statusCode()/100 == 2))
          {
             //?dcm? modify local target; 12.2.2 of 3261 implies that the remote
@@ -404,7 +406,7 @@ Dialog::dispatch(const SipMessage& msg)
 
    DebugLog ( << "Dialog::dispatch: " << msg.brief());
 
-   if(msg.isExternal())
+   if(msg.isFromWire())
    {
       TransportType receivedTransport = toTransportType(
          msg.header(h_Vias).front().transport());
@@ -563,7 +565,7 @@ Dialog::dispatch(const SipMessage& msg)
                      (request.exists(h_Requires) &&
                      request.header(h_Requires).find(Token("norefersub"))))
                {
-                  assert(mInviteSession);
+                  resip_assert(mInviteSession);
                   mInviteSession->referNoSub(msg);
                }
                else
@@ -633,7 +635,7 @@ Dialog::dispatch(const SipMessage& msg)
             }
             break;
         default:
-           assert(0);
+           resip_assert(0);
            return;
       }
    }
@@ -653,7 +655,7 @@ Dialog::dispatch(const SipMessage& msg)
             {
                InfoLog( << "about to re-send request with digest credentials" << r->second->brief());
 
-               assert (r->second->isRequest());
+               resip_assert (r->second->isRequest());
 
                mLocalCSeq++;
                send(r->second);
@@ -719,7 +721,7 @@ Dialog::dispatch(const SipMessage& msg)
             // else drop on the floor
             break;       
 
-		 case REFER:
+         case REFER:
             if(mInviteSession)
             {
                if (code >= 300)
@@ -751,33 +753,6 @@ Dialog::dispatch(const SipMessage& msg)
             {
                client->dispatch(response);
             }
-            else if (code < 300)
-            {
-               /*
-                  we're capturing the  value from the expires header off
-                  the 2xx because the ClientSubscription is only created
-                  after receiving the NOTIFY that comes (usually) after
-                  this 2xx.  We really should be creating the
-                  ClientSubscription at either the 2xx or the NOTIFY
-                  whichever arrives first. .mjf.
-                  Note: we're capturing a duration here (not the
-                  absolute time because all the inputs to
-                  ClientSubscription desling with the expiration are expecting
-                  duration type values from the headers. .mjf.
-                */
-               if(response.exists(h_Expires))
-               {
-                  mDefaultSubExpiration = response.header(h_Expires).value();
-               }
-               else
-               {
-                  //?dcm? defaults to 3600 in ClientSubscription if no expires value
-                  //is provided anywhere...should we assume the value from the
-                  //sub in the basecreator if it exists?
-                  mDefaultSubExpiration = 0;
-               }               
-               return;
-            }
             else
             {
                //!dcm! -- can't subscribe in an existing Dialog, this is all
@@ -833,41 +808,9 @@ Dialog::dispatch(const SipMessage& msg)
          }
          break;
          default:
-            assert(0);
+            resip_assert(0);
             return;
       }
-
-#if 0     // merged from head back to teltel-branch
-      if (msg.header(h_StatusLine).statusCode() >= 400
-          && Helper::determineFailureMessageEffect(msg) == Helper::DialogTermination)
-      {
-         //kill all usages
-         mDestroying = true;
-
-         for (list<ServerSubscription*>::iterator it = mServerSubscriptions.begin();
-              it != mServerSubscriptions.end(); )
-         {
-            ServerSubscription* s = *it;
-            it++;
-            s->dialogDestroyed(msg);
-         }
-
-         for (list<ClientSubscription*>::iterator it = mClientSubscriptions.begin();
-              it != mClientSubscriptions.end(); )
-         {
-            ClientSubscription* s = *it;
-            it++;
-            s->dialogDestroyed(msg);
-         }
-         if (mInviteSession)
-         {
-            mInviteSession->dialogDestroyed(msg);
-         }
-         mDestroying = false;
-         possiblyDie(); //should aways result in destruction of this
-         return;
-      }
-#endif
    }
 }
 
@@ -992,7 +935,7 @@ Dialog::redirected(const SipMessage& msg)
 }
 
 void
-Dialog::makeRequest(SipMessage& request, MethodTypes method)
+Dialog::makeRequest(SipMessage& request, MethodTypes method, bool incrementCSeq)
 {
    RequestLine rLine(method);
 
@@ -1026,13 +969,16 @@ Dialog::makeRequest(SipMessage& request, MethodTypes method)
    }
    else
    {
-      assert(request.exists(h_Vias));
+      resip_assert(request.exists(h_Vias));
    }
 
    //don't increment CSeq for ACK or CANCEL
    if (method != ACK && method != CANCEL)
    {
-      request.header(h_CSeq).sequence() = ++mLocalCSeq;
+      if(incrementCSeq)
+      {
+         setRequestNextCSeq(request);
+      }
    }
    else
    {
@@ -1062,16 +1008,15 @@ Dialog::makeRequest(SipMessage& request, MethodTypes method)
    DebugLog ( << "Dialog::makeRequest: " << std::endl << std::endl << request );
 }
 
-
 void
 Dialog::makeResponse(SipMessage& response, const SipMessage& request, int code)
 {
-   assert( code >= 100 );
+   resip_assert( code >= 100 );
    response.remove(h_Contacts);
    if (code < 300 && code > 100)
    {
-      assert(request.isRequest());
-      assert(request.header(h_RequestLine).getMethod() == INVITE ||
+      resip_assert(request.isRequest());
+      resip_assert(request.header(h_RequestLine).getMethod() == INVITE ||
              request.header(h_RequestLine).getMethod() == SUBSCRIBE ||
              request.header(h_RequestLine).getMethod() == BYE ||
              request.header(h_RequestLine).getMethod() == CANCEL ||
@@ -1108,6 +1053,12 @@ Dialog::makeResponse(SipMessage& response, const SipMessage& request, int code)
    DebugLog ( << "Dialog::makeResponse: " << std::endl << std::endl << response);
 }
 
+void 
+Dialog::setRequestNextCSeq(SipMessage& request)
+{
+   resip_assert(request.isRequest() && request.method() != ACK && request.method() != CANCEL);
+   request.header(h_CSeq).sequence() = ++mLocalCSeq;
+}
 
 ClientInviteSession*
 Dialog::makeClientInviteSession(const SipMessage& response)
@@ -1115,7 +1066,7 @@ Dialog::makeClientInviteSession(const SipMessage& response)
    InviteSessionCreator* creator = dynamic_cast<InviteSessionCreator*>(mDialogSet.getCreator());
    if (!creator)
    {
-      assert(0); // !jf! this maybe can assert by evil UAS
+      resip_assert(0); // !jf! this maybe can assert by evil UAS
       return 0;
    }
    //return mDum.createAppClientInviteSession(*this, *creator);
@@ -1123,15 +1074,12 @@ Dialog::makeClientInviteSession(const SipMessage& response)
                                   creator->getInitialOffer(), creator->getEncryptionLevel(), creator->getServerSubscription());
 }
 
-
-
 ClientSubscription*
 Dialog::makeClientSubscription(const SipMessage& request)
 {
-   return new ClientSubscription(mDum, *this, request, mDefaultSubExpiration);
+   return new ClientSubscription(mDum, *this, request);
 }
 
-
 ServerInviteSession*
 Dialog::makeServerInviteSession(const SipMessage& request)
 {
