@@ -50,7 +50,7 @@ const Data& InviteSession::getEndReasonString(InviteSession::EndReason reason)
 {
    if(reason != InviteSession::UserSpecified)
    {
-      assert(reason >= InviteSession::NotSpecified && reason < InviteSession::ENDREASON_MAX); //!dcm! -- necessary?
+      resip_assert(reason >= InviteSession::NotSpecified && reason < InviteSession::ENDREASON_MAX); //!dcm! -- necessary?
       return EndReasons[reason];
    }
    else
@@ -81,7 +81,7 @@ InviteSession::InviteSession(DialogUsageManager& dum, Dialog& dialog)
      mEndReason(NotSpecified)
 {
    DebugLog ( << "^^^ InviteSession::InviteSession " << this);
-   assert(mDum.mInviteSessionHandler);
+   resip_assert(mDum.mInviteSessionHandler);
 }
 
 InviteSession::~InviteSession()
@@ -95,17 +95,6 @@ InviteSession::~InviteSession()
    }
 }
 
-void 
-InviteSession::dialogDestroyed(const SipMessage& msg)
-{
-   assert(0);
-   
-   // !jf! Is this correct? Merged from main...
-   // !jf! what reason - guessed for now?
-   //mDum.mInviteSessionHandler->onTerminated(getSessionHandle(), InviteSessionHandler::PeerEnded, msg);   
-   //delete this;   
-}
-
 bool
 InviteSession::hasLocalOfferAnswer() const
 {
@@ -166,18 +155,18 @@ InviteSession::getProposedRemoteOfferAnswer() const
 bool
 InviteSession::hasLocalSdp() const
 {
-   assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
+   resip_assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
    return (mCurrentLocalOfferAnswer.get());
 }
 
 const SdpContents&
 InviteSession::getLocalSdp() const
 {
-   assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
+   resip_assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
    if(mCurrentLocalOfferAnswer.get())
    {
       const SdpContents* sdp = dynamic_cast<const SdpContents*>(mCurrentLocalOfferAnswer.get());
-      assert(sdp);
+      resip_assert(sdp);
       return *sdp;
    }
    else
@@ -189,18 +178,18 @@ InviteSession::getLocalSdp() const
 bool
 InviteSession::hasRemoteSdp() const
 {
-   assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
+   resip_assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
    return (mCurrentRemoteOfferAnswer.get());
 }
 
 const SdpContents&
 InviteSession::getRemoteSdp() const
 {
-   assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
+   resip_assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
    if(mCurrentRemoteOfferAnswer.get())
    {
       const SdpContents* sdp = dynamic_cast<const SdpContents*>(mCurrentRemoteOfferAnswer.get());
-      assert(sdp);
+      resip_assert(sdp);
       return *sdp;
    }
    else
@@ -212,18 +201,18 @@ InviteSession::getRemoteSdp() const
 bool
 InviteSession::hasProposedRemoteSdp() const
 {
-   assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
+   resip_assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
    return (mProposedRemoteOfferAnswer.get());
 }
 
 const SdpContents&
 InviteSession::getProposedRemoteSdp() const
 {
-   assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
+   resip_assert(!mDum.mInviteSessionHandler->isGenericOfferAnswer());
    if(mProposedRemoteOfferAnswer.get())
    {
       const SdpContents* sdp = dynamic_cast<const SdpContents*>(mProposedRemoteOfferAnswer.get());
-      assert(sdp);
+      resip_assert(sdp);
       return *sdp;
    }
    else
@@ -461,7 +450,7 @@ InviteSession::provideOffer(const Contents& offer,
          break;
 
       case ReceivedReinviteNoOffer:
-         assert(!mProposedRemoteOfferAnswer.get());
+         resip_assert(!mProposedRemoteOfferAnswer.get());
          transition(ReceivedReinviteSentOffer);
          mDialog.makeResponse(*mInvite200, *mLastRemoteSessionModification, 200);
          handleSessionTimerRequest(*mInvite200, *mLastRemoteSessionModification);
@@ -727,7 +716,7 @@ InviteSession::end(EndReason reason)
          break;
 
       default:
-         assert(0);
+         resip_assert(0);
          break;
    }
 }
@@ -796,7 +785,7 @@ InviteSession::reject(int statusCode, WarningCategory *warning)
          break;
       }
       default:
-         assert(0);
+         resip_assert(0);
          break;
    }
 }
@@ -861,7 +850,7 @@ InviteSession::refer(const NameAddr& referTo, std::auto_ptr<resip::Contents> con
    if (isConnected()) // ?slg? likely not safe in any state except Connected - what should behaviour be if state is ReceivedReinvite?
    {
       SharedPtr<SipMessage> refer(new SipMessage());
-      mDialog.makeRequest(*refer, REFER);
+      mDialog.makeRequest(*refer, REFER, mNitState == NitComplete);  // only increment CSeq if not going to queue NIT
       refer->header(h_ReferTo) = referTo;
       refer->header(h_ReferredBy) = myAddr(); 
       refer->header(h_ReferredBy).remove(p_tag);   // tag-param not permitted in rfc3892; not the same as generic-param
@@ -887,7 +876,6 @@ InviteSession::refer(const NameAddr& referTo, std::auto_ptr<resip::Contents> con
    else
    {
       WarningLog (<< "Can't refer before Connected");
-      assert(0);
       throw UsageUseException("REFER not allowed in this context", __FILE__, __LINE__);
    }
 }
@@ -909,6 +897,7 @@ InviteSession::nitComplete()
       mNitState = NitProceeding;
       mReferSub = qn->referSubscription();
       mLastSentNITRequest = qn->getNIT();
+      mDialog.setRequestNextCSeq(*mLastSentNITRequest.get());
       InfoLog(<< "checkNITQueue - sending queued NIT:" << mLastSentNITRequest->brief());
       send(mLastSentNITRequest);
       delete qn;
@@ -985,8 +974,8 @@ InviteSession::refer(const NameAddr& referTo, const CallId& replaces, std::auto_
 {
    if (isConnected())  // ?slg? likely not safe in any state except Connected - what should behaviour be if state is ReceivedReinvite?
    {
-      SharedPtr<SipMessage> refer(new SipMessage());      
-      mDialog.makeRequest(*refer, REFER);
+      SharedPtr<SipMessage> refer(new SipMessage());
+      mDialog.makeRequest(*refer, REFER, mNitState == NitComplete);  // only increment CSeq if not going to queue NIT
       refer->setContents(contents);
       refer->header(h_ReferTo) = referTo;
       refer->header(h_ReferredBy) = myAddr();
@@ -1015,7 +1004,7 @@ InviteSession::refer(const NameAddr& referTo, const CallId& replaces, std::auto_
    else
    {
       WarningLog (<< "Can't refer before Connected");
-      assert(0);
+      resip_assert(0);
       throw UsageUseException("REFER not allowed in this context", __FILE__, __LINE__);
    }
 }
@@ -1061,7 +1050,7 @@ void
 InviteSession::info(const Contents& contents)
 {
    SharedPtr<SipMessage> info(new SipMessage());
-   mDialog.makeRequest(*info, INFO);
+   mDialog.makeRequest(*info, INFO, mNitState == NitComplete);  // only increment CSeq if not going to queue NIT
    // !jf! handle multipart here
    info->setContents(&contents);
    DumHelper::setOutgoingEncryptionLevel(*info, mCurrentEncryptionLevel);
@@ -1113,7 +1102,7 @@ void
 InviteSession::message(const Contents& contents)
 {
    SharedPtr<SipMessage> message(new SipMessage());
-   mDialog.makeRequest(*message, MESSAGE);
+   mDialog.makeRequest(*message, MESSAGE, mNitState == NitComplete);  // only increment CSeq if not going to queue NIT
    // !jf! handle multipart here
    message->setContents(&contents);
    DumHelper::setOutgoingEncryptionLevel(*message, mCurrentEncryptionLevel);
@@ -1231,7 +1220,7 @@ InviteSession::dispatch(const SipMessage& msg)
          break;
       case Undefined:
       default:
-         assert(0);
+         resip_assert(0);
          break;
    }
 }
@@ -1277,7 +1266,7 @@ InviteSession::dispatch(const DumTimeout& timeout)
             else if(mState == WaitingToOffer || 
                     mState == UAS_WaitingToOffer)
             {
-               assert(mProposedLocalOfferAnswer.get());
+               resip_assert(mProposedLocalOfferAnswer.get());
                mDum.mInviteSessionHandler->onAckNotReceived(getSessionHandle());
                if(!isTerminated())  
                {
@@ -1445,7 +1434,7 @@ InviteSession::dispatchConnected(const SipMessage& msg)
       case OnUpdateRejected:
       case On200Update:
          WarningLog (<< "DUM delivered an UPDATE response in an incorrect state " << endl << msg);
-         assert(0);
+         resip_assert(0);
          break;
 
       case OnAck:
@@ -1926,7 +1915,7 @@ InviteSession::dispatchWaitingToOffer(const SipMessage& msg)
 {
    if (msg.isRequest() && msg.header(h_RequestLine).method() == ACK)
    {
-      assert(mProposedLocalOfferAnswer.get());
+      resip_assert(mProposedLocalOfferAnswer.get());
       mCurrentRetransmit200 = 0; // stop the 200 retransmit timer
       provideProposedOffer(); 
    }
@@ -2065,7 +2054,7 @@ InviteSession::dispatchOthers(const SipMessage& msg)
                      << " to the InviteSession in state: " << toData(mState)
                      << endl
                      << msg);
-         assert(0);
+         resip_assert(0);
          break;
    }
 }
@@ -2073,8 +2062,8 @@ InviteSession::dispatchOthers(const SipMessage& msg)
 void
 InviteSession::dispatchUnhandledInvite(const SipMessage& msg)
 {
-   assert(msg.isRequest());
-   assert(msg.header(h_CSeq).method() == INVITE);
+   resip_assert(msg.isRequest());
+   resip_assert(msg.header(h_CSeq).method() == INVITE);
 
    // If we get an INVITE request from the wire and we are not in
    // Connected state, reject the request and send a BYE
@@ -2091,7 +2080,7 @@ InviteSession::dispatchUnhandledInvite(const SipMessage& msg)
 void
 InviteSession::dispatchPrack(const SipMessage& msg)
 {
-   assert(msg.header(h_CSeq).method() == PRACK);
+   resip_assert(msg.header(h_CSeq).method() == PRACK);
    if(msg.isRequest())
    {
       SharedPtr<SipMessage> rsp(new SipMessage);
@@ -2113,7 +2102,7 @@ void
 InviteSession::dispatchCancel(const SipMessage& msg)
 {
    InviteSessionHandler* handler = mDum.mInviteSessionHandler;
-   assert(msg.header(h_CSeq).method() == CANCEL);
+   resip_assert(msg.header(h_CSeq).method() == CANCEL);
    if(msg.isRequest())
    {
       SharedPtr<SipMessage> rsp(new SipMessage);
@@ -2129,7 +2118,7 @@ InviteSession::dispatchCancel(const SipMessage& msg)
    else
    {
       WarningLog (<< "DUM let me send a CANCEL at an incorrect state " << endl << msg);
-      assert(0);
+      resip_assert(0);
    }
 }
 
@@ -2170,7 +2159,7 @@ InviteSession::dispatchBye(const SipMessage& msg)
    else
    {
       WarningLog (<< "DUM let me send a BYE at an incorrect state " << endl << msg);
-      assert(0);
+      resip_assert(0);
    }
 }
 
@@ -2200,7 +2189,7 @@ InviteSession::dispatchInfo(const SipMessage& msg)
    }
    else
    {
-      assert(mNitState == NitProceeding);
+      resip_assert(mNitState == NitProceeding);
       //!dcm! -- toss away 1xx to an info?
       if (msg.header(h_StatusLine).statusCode() >= 300)
       {
@@ -2347,7 +2336,7 @@ InviteSession::dispatchMessage(const SipMessage& msg)
    }
    else
    {
-      assert(mNitState == NitProceeding);
+      resip_assert(mNitState == NitProceeding);
       //!dcm! -- toss away 1xx to an message?
       if (msg.header(h_StatusLine).statusCode() >= 300)
       {
@@ -2426,7 +2415,11 @@ InviteSession::setSessionTimerHeaders(SipMessage &msg)
       {
          msg.header(h_SessionExpires).param(p_refresher) = Data(mSessionRefresher ? "uas" : "uac");
       }
-      msg.header(h_MinSE).value() = mMinSE;
+      if(msg.isRequest() || 
+         (msg.isResponse() && msg.header(h_StatusLine).responseCode() == 422))
+      {
+         msg.header(h_MinSE).value() = mMinSE;
+      }
    }
    else
    {
@@ -2512,7 +2505,7 @@ InviteSession::startSessionTimer()
 void
 InviteSession::handleSessionTimerResponse(const SipMessage& msg)
 {
-   assert(msg.header(h_CSeq).method() == INVITE || msg.header(h_CSeq).method() == UPDATE);
+   resip_assert(msg.header(h_CSeq).method() == INVITE || msg.header(h_CSeq).method() == UPDATE);
 
    // Allow Re-Invites and Updates to update the Peer P-Asserted-Identity
    if (msg.exists(h_PAssertedIdentities))
@@ -2562,7 +2555,7 @@ InviteSession::handleSessionTimerResponse(const SipMessage& msg)
 void
 InviteSession::handleSessionTimerRequest(SipMessage &response, const SipMessage& request)
 {
-   assert(request.header(h_CSeq).method() == INVITE || request.header(h_CSeq).method() == UPDATE);
+   resip_assert(request.header(h_CSeq).method() == INVITE || request.header(h_CSeq).method() == UPDATE);
 
    // Allow Re-Invites and Updates to update the Peer P-Asserted-Identity
    if (request.exists(h_PAssertedIdentities))
@@ -2743,7 +2736,7 @@ InviteSession::toData(State state)
       case UAS_WaitingToRequestOffer:
          return "UAS_WaitingToRequestOffer";
    }
-   assert(0);
+   resip_assert(0);
    return "Undefined";
 }
 
@@ -2844,7 +2837,7 @@ InviteSession::setOfferAnswer(SipMessage& msg, const Contents& offerAnswer, cons
 void
 InviteSession::setOfferAnswer(SipMessage& msg, const Contents* offerAnswer)
 {
-   assert(offerAnswer);
+   resip_assert(offerAnswer);
    msg.setContents(offerAnswer);
 }
 
@@ -3069,7 +3062,7 @@ InviteSession::sendAck(const Contents *answer)
       source = mLastLocalSessionModification;
    }
 
-   assert(mAcks.count(source->getTransactionId()) == 0);
+   resip_assert(mAcks.count(source->getTransactionId()) == 0);
 
    mDialog.makeRequest(*ack, ACK);
 
@@ -3143,7 +3136,7 @@ InviteSession::getEncryptionLevel(const SipMessage& msg)
 void 
 InviteSession::setCurrentLocalOfferAnswer(const SipMessage& msg)
 {
-   assert(mProposedLocalOfferAnswer.get());
+   resip_assert(mProposedLocalOfferAnswer.get());
    if (dynamic_cast<MultipartAlternativeContents*>(mProposedLocalOfferAnswer.get()))
    {
       if (DialogUsageManager::Encrypt == getEncryptionLevel(msg) || DialogUsageManager::SignAndEncrypt == getEncryptionLevel(msg))
@@ -3178,7 +3171,7 @@ InviteSession::flowTerminated()
 void 
 InviteSession::referNoSub(const SipMessage& msg)
 {
-   assert(msg.isRequest() && msg.header(h_CSeq).method()==REFER);
+   resip_assert(msg.isRequest() && msg.header(h_CSeq).method()==REFER);
    mLastReferNoSubRequest = msg;
    mDum.mInviteSessionHandler->onReferNoSub(getSessionHandle(), mLastReferNoSubRequest);
 }
