@@ -6,7 +6,7 @@
 #include <rutil/Logger.hxx>
 #include <rutil/DnsUtil.hxx>
 #include <rutil/MD5Stream.hxx>
-#include "rutil/FdPoll.hxx"
+#include <rutil/FdPoll.hxx>
 #include <resip/stack/SdpContents.hxx>
 #include <resip/stack/PlainContents.hxx>
 #include <resip/stack/ConnectionTerminated.hxx>
@@ -156,13 +156,13 @@ BasicClientUserAgent::BasicClientUserAgent(int argc, char** argv) :
    mProfile->addSupportedMethod(CANCEL);
    mProfile->addSupportedMethod(OPTIONS);
    mProfile->addSupportedMethod(BYE);
-   //mProfile->addSupportedMethod(REFER);    
-   mProfile->addSupportedMethod(NOTIFY);    
-   mProfile->addSupportedMethod(SUBSCRIBE); 
-   //mProfile->addSupportedMethod(UPDATE);    
-   mProfile->addSupportedMethod(INFO);    
-   mProfile->addSupportedMethod(MESSAGE);    
-   //mProfile->addSupportedMethod(PRACK);     
+   //mProfile->addSupportedMethod(REFER);
+   mProfile->addSupportedMethod(NOTIFY);
+   mProfile->addSupportedMethod(SUBSCRIBE);
+   //mProfile->addSupportedMethod(UPDATE);
+   mProfile->addSupportedMethod(INFO);
+   mProfile->addSupportedMethod(MESSAGE);
+   mProfile->addSupportedMethod(PRACK);
    //mProfile->addSupportedOptionTag(Token(Symbols::C100rel));  // Automatically added when using setUacReliableProvisionalMode
    mProfile->setUacReliableProvisionalMode(MasterProfile::Supported);
    mProfile->setUasReliableProvisionalMode(MasterProfile::SupportedEssential);  
