@@ -61,7 +61,7 @@ class MediaResourceParticipantDeleterCmd : public DumCommand
 
       void executeCommand() { Participant* participant = mConversationManager.getParticipant(mParticipantHandle); if(participant) delete participant; }
 
-      Message* clone() const { assert(0); return 0; }
+      Message* clone() const { resip_assert(0); return 0; }
       EncodeStream& encode(EncodeStream& strm) const { strm << "MediaResourceParticipantDeleterCmd: partHandle=" << mParticipantHandle; return strm; }
       EncodeStream& encodeBrief(EncodeStream& strm) const { return encode(strm); }
       
@@ -146,7 +146,7 @@ MediaResourceParticipant::~MediaResourceParticipant()
 void 
 MediaResourceParticipant::startPlay()
 {
-   assert(!mPlaying);
+   resip_assert(!mPlaying);
    try
    {
       InfoLog(<< "MediaResourceParticipant playing, handle=" << mHandle << " url=" << mMediaUrl);
@@ -216,9 +216,9 @@ MediaResourceParticipant::startPlay()
             {
                StackLog(<<"sending tone to sipX connection: " << participant->getMediaConnectionId());
                // this uses the original API, where both inband and RFC2833 tones are always sent simultaneously:
-               //status = getMediaInterface()->getInterface()->startChannelTone(participant->getMediaConnectionId(), toneid, mRemoteOnly ? FALSE : TRUE /* local */, mLocalOnly ? FALSE : TRUE /* remote */);
+               status = getMediaInterface()->getInterface()->startChannelTone(participant->getMediaConnectionId(), toneid, mRemoteOnly ? FALSE : TRUE /* local */, mLocalOnly ? FALSE : TRUE /* remote */);
                // this is for newer sipXtapi API, option to suppress inband tones:
-               status = getMediaInterface()->getInterface()->startChannelTone(participant->getMediaConnectionId(), toneid, mRemoteOnly ? FALSE : TRUE /* local */, mLocalOnly ? FALSE : TRUE /* remote */, !isDtmf /* inband */, true /* RFC 4733 */);
+               //status = getMediaInterface()->getInterface()->startChannelTone(participant->getMediaConnectionId(), toneid, mRemoteOnly ? FALSE : TRUE /* local */, mLocalOnly ? FALSE : TRUE /* remote */, !isDtmf /* inband */, true /* RFC 4733 */);
             }
             else
             {
@@ -373,7 +373,7 @@ MediaResourceParticipant::getConnectionPortOnBridge()
    case Tone:     
       if(mToneGenPortOnBridge == -1)
       {
-         assert(getMediaInterface() != 0);     
+         resip_assert(getMediaInterface() != 0);     
          ((CpTopologyGraphInterface*)getMediaInterface()->getInterface())->getResourceInputPortOnBridge(DEFAULT_TONE_GEN_RESOURCE_NAME,0,mToneGenPortOnBridge);
          InfoLog(<< "MediaResourceParticipant getConnectionPortOnBridge, handle=" << mHandle << ", mToneGenPortOnBridge=" << mToneGenPortOnBridge);
       }
@@ -385,7 +385,7 @@ MediaResourceParticipant::getConnectionPortOnBridge()
    case Https:
       if(mFromFilePortOnBridge == -1)
       {
-         assert(getMediaInterface() != 0);     
+         resip_assert(getMediaInterface() != 0);     
          ((CpTopologyGraphInterface*)getMediaInterface()->getInterface())->getResourceInputPortOnBridge(DEFAULT_FROM_FILE_RESOURCE_NAME,0,mFromFilePortOnBridge);
          InfoLog(<< "MediaResourceParticipant getConnectionPortOnBridge, handle=" << mHandle << ", mFromFilePortOnBridge=" << mFromFilePortOnBridge);
       }
@@ -421,9 +421,9 @@ MediaResourceParticipant::destroyParticipant()
                if(participant)
                {
                   // this uses the original API, where both inband and RFC2833 tones are always sent simultaneously:
-                  //status = getMediaInterface()->getInterface()->stopChannelTone(participant->getMediaConnectionId());
+                  status = getMediaInterface()->getInterface()->stopChannelTone(participant->getMediaConnectionId());
                   // this is for newer sipXtapi API, option to suppress inband tones:
-                  status = getMediaInterface()->getInterface()->stopChannelTone(participant->getMediaConnectionId(), !isDtmf, true);
+                  //status = getMediaInterface()->getInterface()->stopChannelTone(participant->getMediaConnectionId(), !isDtmf, true);
                }
                else
                {
