@@ -2,7 +2,7 @@
 #include "config.h"
 #endif
 
-#include <cassert>
+#include "rutil/ResipAssert.h"
 #include "rutil/ParseException.hxx"
 #include "resip/stack/ExistsOrDataParameter.hxx"
 #include "resip/stack/Symbols.hxx"
