@@ -27,9 +27,10 @@ InternalTransport::InternalTransport(Fifo<TransactionMessage>& rxFifo,
                                      const Data& interfaceObj,
                                      AfterSocketCreationFuncPtr socketFunc,
                                      Compression &compression,
-                                     unsigned transportFlags) :
+                                     unsigned transportFlags,
+                                     const Data& netNs) :
    Transport(rxFifo, portNum, version, interfaceObj, Data::Empty,
-             socketFunc, compression, transportFlags),
+             socketFunc, compression, transportFlags, netNs),
    mFd(INVALID_SOCKET),
    mInterruptorHandle(0),
    mTxFifoOutBuffer(mTxFifo),
@@ -40,9 +41,13 @@ InternalTransport::InternalTransport(Fifo<TransactionMessage>& rxFifo,
 InternalTransport::~InternalTransport()
 {
    if (mPollItemHandle)
+   {
       mPollGrp->delPollItem(mPollItemHandle);
+   }
    if (mInterruptorHandle)
+   {
       mPollGrp->delPollItem(mInterruptorHandle);
+   }
 
    if  (mFd != INVALID_SOCKET)
    {
@@ -54,6 +59,7 @@ InternalTransport::~InternalTransport()
    {
       WarningLog(<< "TX Fifo non-empty in ~InternalTransport! Has " << mTxFifo.size() << " messages.");
    }
+   setCongestionManager(0);  // Clear out congestion manager
 }
 
 bool
@@ -85,7 +91,7 @@ InternalTransport::socket(TransportType type, IpVersion ipVer)
          break;
       default:
          InfoLog (<< "Try to create an unsupported socket type: " << Tuple::toData(type));
-         assert(0);
+         resip_assert(0);
          throw Transport::Exception("Unsupported transport", __FILE__,__LINE__);
    }
 
@@ -120,7 +126,12 @@ InternalTransport::socket(TransportType type, IpVersion ipVer)
 void
 InternalTransport::bind()
 {
-   DebugLog (<< "Binding to " << Tuple::inet_ntop(mTuple));
+#ifdef USE_NETNS
+   DebugLog (<< "Binding to " << Tuple::inet_ntop(mTuple) 
+             << " in netns=\"" <<mTuple.getNetNs() << "\"");
+#else
+   DebugLog (<< "Binding to " << Tuple::inet_ntop(mTuple)); 
+#endif
 
    if ( ::bind( mFd, &mTuple.getMutableSockaddr(), mTuple.length()) == SOCKET_ERROR )
    {
