@@ -125,6 +125,10 @@ const char* Symbols::id = "id"; // from RFC 3323
 
 const char* Symbols::Gruu = "gruu";
 
+const char* Symbols::Uui = "uui";
+const char* Symbols::Hex = "hex";
+const char* Symbols::IsdnInterwork = "isdn-interwork";
+const char* Symbols::IsdnUui = "isdn-uui";
 
 #if defined(WIN32)
 const char *Symbols::pathSep = "\\";
