@@ -205,6 +205,15 @@ defineParam(appId, "app-id", DataParameter, "draft-ietf-sipping-config-framework
 defineParam(networkUser, "network-user", DataParameter, "draft-ietf-sipping-config-framework-11 (removed in 12)");
 defineParam(require, "require", DataParameter, "RFC 5373");
 
+defineParam(utranCellId3gpp, "utran-cell-id-3gpp", DataParameter, "RFC 3455"); // P-Access-Network-Info
+defineParam(cgi3gpp, "cgi-3gpp", DataParameter, "RFC 3455"); // P-Access-Network-Info
+defineParam(ccf, "ccf", DataParameter, "RFC 3455"); // P-Charging-Function-Addresses
+defineParam(ecf, "ecf", DataParameter, "RFC 3455"); // P-Charging-Function-Addresses
+defineParam(icidValue, "icid-value", DataParameter, "RFC 3455"); // P-Charging-Vector
+defineParam(icidGeneratedAt, "icid-generated-at", DataParameter, "RFC 3455"); // P-Charging-Vector
+defineParam(origIoi, "orig-ioi", DataParameter, "RFC 3455"); // P-Charging-Vector
+defineParam(termIoi, "term-ioi", DataParameter, "RFC 3455"); // P-Charging-Vector
+
 #undef defineParam
 
 /* ====================================================================
