@@ -120,7 +120,8 @@ UdpTransport::setPollGrp(FdPollGrp *grp)
  * Called after a message is added. Could try writing it now.
  */
 void
-UdpTransport::process() {
+UdpTransport::process() 
+{
    mStateMachineFifo.flush();
    if ( (mTransportFlags & RESIP_TRANSPORT_FLAG_TXNOW)!= 0 )
    {
@@ -129,8 +130,11 @@ UdpTransport::process() {
        // shouldn't ever happen (with current code)
        // but in future we may throttle transmits
    }
+
    if ( mPollGrp )
+   {
        updateEvents();
+   }
 }
 
 void
@@ -157,7 +161,7 @@ UdpTransport::processPollEvent(FdPollEventMask mask)
    ++mPollEventCnt;
    if ( mask & FPEM_Error )
    {
-      assert(0);
+      resip_assert(0);
    }
    if ( mask & FPEM_Write )
    {
@@ -226,19 +230,26 @@ UdpTransport::processTxAll()
       processTxOne(msg);
       // With UDP we don't need to worry about write blocking (I hope)
       if ( (mTransportFlags & RESIP_TRANSPORT_FLAG_TXALL)==0 )
+      {
          break;
+      }
    }
 }
 
 void
 UdpTransport::processTxOne(SendData *data)
 {
+   resip_assert(data);
+   if(data->command != SendData::NoCommand)
+   {
+      // We don't handle any special SendData commands in the UDP transport yet.
+      return;
+   }
    ++mTxMsgCnt;
-   assert(data);
    std::auto_ptr<SendData> sendData(data);
    //DebugLog (<< "Sent: " <<  sendData->data);
    //DebugLog (<< "Sending message on udp.");
-   assert( sendData->destination.getPort() != 0 );
+   resip_assert( sendData->destination.getPort() != 0 );
 
    const sockaddr& addr = sendData->destination.getSockaddr();
    int expected;
@@ -331,7 +342,7 @@ UdpTransport::processRxAll()
    }
    if ( buffer && (mTransportFlags & RESIP_TRANSPORT_FLAG_KEEP_BUFFER)!=0 )
    {
-      assert(mRxBuffer==NULL);
+      resip_assert(mRxBuffer==NULL);
       mRxBuffer = buffer;
       buffer = NULL;
    }
@@ -379,7 +390,7 @@ UdpTransport::processRxRecv(char*& buffer, Tuple& sender)
       if ( len == SOCKET_ERROR )
       {
          int err = getErrno();
-         if ( err != EWOULDBLOCK  )
+         if ( err != EAGAIN && err != EWOULDBLOCK ) // Treat EGAIN and EWOULDBLOCK as the same: http://stackoverflow.com/questions/7003234/which-systems-define-eagain-and-ewouldblock-as-different-values
          {
             error( err );
          }
@@ -557,7 +568,7 @@ UdpTransport::processRxParse(char *buffer, int len, Tuple& sender)
    //DebugLog ( << "UDP Rcv : " << len << " b" );
    //DebugLog ( << Data(buffer, len).escaped().c_str());
 
-   SipMessage* message = new SipMessage(this);
+   SipMessage* message = new SipMessage(&mTuple);
 
    // set the received from information into the received= parameter in the
    // via
@@ -565,11 +576,7 @@ UdpTransport::processRxParse(char *buffer, int len, Tuple& sender)
    // It is presumed that UDP Datagrams are arriving atomically and that
    // each one is a unique SIP message
 
-
    // Save all the info where this message came from
-   sender.transport = this;
-   sender.transportKey = getKey();
-   sender.mFlowKey=mTuple.mFlowKey;
    message->setSource(sender);
    //DebugLog (<< "Received from: " << sender);
 
@@ -693,7 +700,7 @@ UdpTransport::processRxParse(char *buffer, int len, Tuple& sender)
    }
 #endif
 
-   mStateMachineFifo.add(message);
+   pushRxMsgUp(message);
    ++mRxTransactionCnt;
    return origBufferConsumed;
 }
