@@ -81,7 +81,9 @@ DtlsTransport::DtlsTransport(Fifo<TransactionMessage>& fifo,
                              const Data& sipDomain,
                              AfterSocketCreationFuncPtr socketFunc,
                              Compression& compression,
-                             const Data& certificateFilename, const Data& privateKeyFilename)
+                             const Data& certificateFilename, 
+                             const Data& privateKeyFilename,
+                             const Data& privateKeyPassPhrase)
  : UdpTransport( fifo, portNum, version, StunDisabled, interfaceObj, socketFunc, compression ),
    mTimer( mHandshakePending ),
    mSecurity( &security ),
@@ -101,13 +103,13 @@ DtlsTransport::DtlsTransport(Fifo<TransactionMessage>& fifo,
 
    mTuple.setType( DTLS );
 
-   mClientCtx = mSecurity->createDomainCtx(DTLSv1_client_method(), Data::Empty, certificateFilename, privateKeyFilename) ;
-   mServerCtx = mSecurity->createDomainCtx(DTLSv1_server_method(), sipDomain, certificateFilename, privateKeyFilename) ;
-   assert( mClientCtx ) ;
-   assert( mServerCtx ) ;
+   mClientCtx = mSecurity->createDomainCtx(DTLSv1_client_method(), Data::Empty, certificateFilename, privateKeyFilename, privateKeyPassPhrase) ;
+   mServerCtx = mSecurity->createDomainCtx(DTLSv1_server_method(), sipDomain, certificateFilename, privateKeyFilename, privateKeyPassPhrase) ;
+   resip_assert( mClientCtx ) ;
+   resip_assert( mServerCtx ) ;
 
    mDummyBio = BIO_new( BIO_s_mem() ) ;
-   assert( mDummyBio ) ;
+   resip_assert( mDummyBio ) ;
 
    mSendData = NULL ;
 
@@ -166,7 +168,7 @@ DtlsTransport::_read( FdSet& fdset )
    if ( len == SOCKET_ERROR )
    {
       int err = getErrno() ;
-      if ( err != EWOULDBLOCK  )
+      if ( err != EAGAIN && err != EWOULDBLOCK ) // Treat EGAIN and EWOULDBLOCK as the same: http://stackoverflow.com/questions/7003234/which-systems-define-eagain-and-ewouldblock-as-different-values
       {
          error( err ) ;
       }
@@ -202,7 +204,7 @@ DtlsTransport::_read( FdSet& fdset )
    if ( ssl == NULL )
    {
       ssl = SSL_new( mServerCtx ) ;
-      assert( ssl ) ;
+      resip_assert( ssl ) ;
 
       // clear SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE set in SSL_CTX if we are a server
       SSL_set_verify(ssl, 0, 0);
@@ -212,7 +214,7 @@ DtlsTransport::_read( FdSet& fdset )
       SSL_set_accept_state( ssl ) ;
 
       wbio = BIO_new_dgram( (int)mFd, BIO_NOCLOSE ) ;
-      assert( wbio ) ;
+      resip_assert( wbio ) ;
 
       BIO_dgram_set_peer( wbio, &peer ) ;
 
@@ -340,7 +342,7 @@ DtlsTransport::_read( FdSet& fdset )
 #endif
    }
 
-   SipMessage* message = new SipMessage(this);
+   SipMessage* message = new SipMessage(&mTuple);
 
    // set the received from information into the received= parameter in the
    // via
@@ -349,7 +351,6 @@ DtlsTransport::_read( FdSet& fdset )
    // each one is a unique SIP message
 
    // Save all the info where this message came from
-   tuple.transport = this ;
    message->setSource( tuple ) ;
    //DebugLog (<< "Received from: " << tuple);
 
@@ -434,7 +435,7 @@ DtlsTransport::_read( FdSet& fdset )
       }
 #endif
 
-   mStateMachineFifo.add( message ) ;
+   pushRxMsgUp(message);
 }
 
 void DtlsTransport::_write( FdSet& fdset )
@@ -452,8 +453,8 @@ void DtlsTransport::_write( FdSet& fdset )
    //DebugLog (<< "Sent: " <<  sendData->data);
    //DebugLog (<< "Sending message on udp.");
 
-   assert( &(*sendData) );
-   assert( sendData->destination.getPort() != 0 );
+   resip_assert( &(*sendData) );
+   resip_assert( sendData->destination.getPort() != 0 );
 
    sockaddr peer = sendData->destination.getSockaddr();
 
@@ -463,7 +464,7 @@ void DtlsTransport::_write( FdSet& fdset )
    if ( ssl == NULL )
    {
       ssl = SSL_new( mClientCtx ) ;
-      assert( ssl ) ;
+      resip_assert( ssl ) ;
 
 
       InfoLog( << "DTLS handshake starting (client mode)" );
@@ -471,7 +472,7 @@ void DtlsTransport::_write( FdSet& fdset )
       SSL_set_connect_state( ssl ) ;
 
       wBio = BIO_new_dgram( (int)mFd, BIO_NOCLOSE ) ;
-      assert( wBio ) ;
+      resip_assert( wBio ) ;
 
       BIO_dgram_set_peer( wBio, &peer) ;
 
