@@ -86,18 +86,18 @@ TlsConnection::TlsConnection( Transport* transport, const Tuple& tuple,
    {
       DebugLog( << "Trying to form TLS connection - acting as client" );
    }
-   assert( mSecurity );
+   resip_assert( mSecurity );
 
    TlsBaseTransport *t = dynamic_cast<TlsBaseTransport*>(transport);
-   assert(t);
+   resip_assert(t);
 
    SSL_CTX* ctx=t->getCtx();
-   assert(ctx);
+   resip_assert(ctx);
    
    mSsl = SSL_new(ctx);
-   assert(mSsl);
+   resip_assert(mSsl);
 
-   assert( mSecurity );
+   resip_assert( mSecurity );
 
    if(mServer)
    {
@@ -118,13 +118,17 @@ TlsConnection::TlsConnection( Transport* transport, const Tuple& tuple,
          DebugLog(<< "Mandatory client certificate mode" );
          break;
       default:
-         assert( 0 );
+         resip_assert( 0 );
       }
       SSL_set_verify(mSsl, verify_mode, 0);
    }
 
    mBio = BIO_new_socket((int)fd,0/*close flag*/);
-   assert( mBio );
+   if( !mBio )
+   {
+      throw Transport::Exception("Failed to create OpenSSL BIO for socket",
+         __FILE__, __LINE__);
+   }
    
    SSL_set_bio( mSsl, mBio, mBio );
 
@@ -266,7 +270,7 @@ TlsConnection::checkState()
                if(e == 0)
                {
                   TlsBaseTransport *t = dynamic_cast<TlsBaseTransport*>(transport());
-                  assert(t);
+                  resip_assert(t);
                   if(mServer && t->getClientVerificationMode() != SecurityTypes::None)
                   {
                      DebugLog(<<"client may have disconnected to prompt for user certificate, because it can't supply a certificate (verification mode == " << (t->getClientVerificationMode() == SecurityTypes::Mandatory?"Mandatory":"Optional") << " for this transport) or because it does not support using client certificates over WebSockets");
@@ -298,7 +302,7 @@ TlsConnection::checkState()
                   if(mServer)
                   {
                      TlsBaseTransport *t = dynamic_cast<TlsBaseTransport*>(transport());
-                     assert(t);
+                     resip_assert(t);
                      if(t->getClientVerificationMode() == SecurityTypes::Mandatory)
                      {
                         ErrLog(<<"Mandatory client certificate verification required, protocol failed, client did not send a certificate or it was not valid");
@@ -369,8 +373,8 @@ int
 TlsConnection::read(char* buf, int count )
 {
 #if defined(USE_SSL)
-   assert( mSsl ); 
-   assert( buf );
+   resip_assert( mSsl ); 
+   resip_assert( buf );
 
    switch(checkState())
    {
@@ -396,7 +400,7 @@ TlsConnection::read(char* buf, int count )
    }
 
    int bytesRead = SSL_read(mSsl,buf,count);
-   StackLog(<< "SSL_read returned " << bytesRead << " bytes [" << Data(Data::Borrow, buf, (bytesRead > 0)?(bytesRead):(0)) << "]");
+   //StackLog(<< "SSL_read returned " << bytesRead << " bytes [" << Data(Data::Borrow, buf, (bytesRead > 0)?(bytesRead):(0)) << "]");
 
    if (bytesRead > 0)
    {
@@ -406,9 +410,9 @@ TlsConnection::read(char* buf, int count )
          char* buffer = getWriteBufferForExtraBytes(bytesPending);
          if (buffer)
          {
-            StackLog(<< "reading remaining buffered bytes");
+            //StackLog(<< "reading remaining buffered bytes");
             bytesPending = SSL_read(mSsl, buffer, bytesPending);
-            StackLog(<< "SSL_read returned  " << bytesPending << " bytes [" << Data(Data::Borrow, buffer, (bytesPending > 0)?(bytesPending):(0)) << "]");
+            //StackLog(<< "SSL_read returned  " << bytesPending << " bytes [" << Data(Data::Borrow, buffer, (bytesPending > 0)?(bytesPending):(0)) << "]");
             
             if (bytesPending > 0)
             {
@@ -416,12 +420,14 @@ TlsConnection::read(char* buf, int count )
             }
             else
             {
+               // This puts the error return code into bytesRead to
+               // be used in the conditional block later in this method.
                bytesRead = bytesPending;
             }
          }
          else
          {
-            assert(0);
+            resip_assert(0);
          }
       }
       else if (bytesPending < 0)
@@ -445,6 +451,12 @@ TlsConnection::read(char* buf, int count )
             return 0;
          }
          break;
+         case SSL_ERROR_ZERO_RETURN:
+         {
+            DebugLog( << "Got SSL_ERROR_ZERO_RETURN (TLS shutdown by peer)");
+            return -1;
+         }
+         break;
          default:
          {
             handleOpenSSLErrorQueue(bytesRead, err, "SSL_read");
@@ -456,7 +468,7 @@ TlsConnection::read(char* buf, int count )
          }
          break;
       }
-      assert(0);
+      resip_assert(0);
    }
    StackLog(<<"SSL bytesRead="<<bytesRead);
    return bytesRead;
@@ -487,7 +499,7 @@ TlsConnection::transportWrite()
          DebugLog(<< "Transportwrite--" << fromState(mTlsState) << " fall through to write");
          return false;
    }
-   assert(0);
+   resip_assert(0);
    return false;
 }
 
@@ -495,8 +507,8 @@ int
 TlsConnection::write( const char* buf, int count )
 {
 #if defined(USE_SSL)
-   assert( mSsl );
-   assert( buf );
+   resip_assert( mSsl );
+   resip_assert( buf );
    int ret;
  
    switch(checkState())
@@ -532,6 +544,12 @@ TlsConnection::write( const char* buf, int count )
             return 0;
          }
          break;
+         case SSL_ERROR_ZERO_RETURN:
+         {
+            DebugLog( << "Got SSL_ERROR_ZERO_RETURN (TLS shutdown by peer)");
+            return -1;
+         }
+         break;
          default:
          {
             handleOpenSSLErrorQueue(ret, err, "SSL_write");
@@ -653,7 +671,7 @@ TlsConnection::computePeerName()
 #if defined(USE_SSL)
    Data commonName;
 
-   assert(mSsl);
+   resip_assert(mSsl);
 
    if (!mBio)
    {
@@ -686,7 +704,7 @@ TlsConnection::computePeerName()
    }
 
    TlsBaseTransport *t = dynamic_cast<TlsBaseTransport*>(mTransport);
-   assert(t);
+   resip_assert(t);
 
    mPeerNames.clear();
    BaseSecurity::getCertNames(cert, mPeerNames,
