@@ -1,6 +1,6 @@
 #include "rutil/Socket.hxx"
 
-#include <cassert>
+#include "rutil/ResipAssert.h"
 #include <iostream>
 #include <fstream>
 #include <stdio.h>
@@ -28,6 +28,11 @@ const Data Log::delim(" | ");
 Log::ThreadData Log::mDefaultLoggerData(0, Log::Cout, Log::Info, NULL, NULL);
 Data Log::mAppName;
 Data Log::mHostname;
+#ifndef WIN32
+int Log::mSyslogFacility = LOG_DAEMON;
+#else
+int Log::mSyslogFacility = -1;
+#endif
 unsigned int Log::MaxLineCount = 0; // no limit by default
 unsigned int Log::MaxByteCount = 0; // no limit by default
 
@@ -106,14 +111,15 @@ LogStaticInitializer::~LogStaticInitializer()
 }
 
 void
-Log::initialize(const char* typed, const char* leveld, const char* appName, const char *logFileName, ExternalLogger* externalLogger)
+Log::initialize(const char* typed, const char* leveld, const char* appName, const char *logFileName, ExternalLogger* externalLogger, const char* syslogFacilityName)
 {
-   Log::initialize(Data(typed), Data(leveld), Data(appName), logFileName, externalLogger);
+   Log::initialize(Data(typed), Data(leveld), Data(appName), logFileName, externalLogger, syslogFacilityName);
 }
 
 void
 Log::initialize(const Data& typed, const Data& leveld, const Data& appName, 
-                const char *logFileName, ExternalLogger* externalLogger)
+                const char *logFileName, ExternalLogger* externalLogger,
+                const Data& syslogFacilityName)
 {
    Type type = Log::Cout;
    if (isEqualNoCase(typed, "cout")) type = Log::Cout;
@@ -124,13 +130,109 @@ Log::initialize(const Data& typed, const Data& leveld, const Data& appName,
    Level level = Log::Info;
    level = toLevel(leveld);
 
-   Log::initialize(type, level, appName, logFileName, externalLogger);
+   Log::initialize(type, level, appName, logFileName, externalLogger, syslogFacilityName);
+}
+
+int
+Log::parseSyslogFacilityName(const Data& facilityName)
+{
+#ifndef WIN32
+   /* In theory, some platforms may not have all the log facilities
+      defined in syslog.h.  Only LOG_USER and LOG_LOCAL[0-7] are considered
+      mandatory.
+      If the compile fails with errors in this method, then the unsupported
+      facility names could be wrapped in conditional logic.
+   */
+   if(facilityName == "LOG_AUTH")
+   {
+      return LOG_AUTH;
+   }
+   else if(facilityName == "LOG_AUTHPRIV")
+   {
+      return LOG_AUTHPRIV;
+   }
+   else if(facilityName == "LOG_CRON")
+   {
+      return LOG_CRON;
+   }
+   else if(facilityName == "LOG_DAEMON")
+   {
+      return LOG_DAEMON;
+   }
+   else if(facilityName == "LOG_FTP")
+   {
+      return LOG_FTP;
+   }
+   else if(facilityName == "LOG_KERN")
+   {
+      return LOG_KERN;
+   }
+   else if(facilityName == "LOG_LOCAL0")
+   {
+      return LOG_LOCAL0;
+   }
+   else if(facilityName == "LOG_LOCAL1")
+   {
+      return LOG_LOCAL1;
+   }
+   else if(facilityName == "LOG_LOCAL2")
+   {
+      return LOG_LOCAL2;
+   }
+   else if(facilityName == "LOG_LOCAL3")
+   {
+      return LOG_LOCAL3;
+   }
+   else if(facilityName == "LOG_LOCAL4")
+   {
+      return LOG_LOCAL4;
+   }
+   else if(facilityName == "LOG_LOCAL5")
+   {
+      return LOG_LOCAL5;
+   }
+   else if(facilityName == "LOG_LOCAL6")
+   {
+      return LOG_LOCAL6;
+   }
+   else if(facilityName == "LOG_LOCAL7")
+   {
+      return LOG_LOCAL7;
+   }
+   else if(facilityName == "LOG_LPR")
+   {
+      return LOG_LPR;
+   }
+   else if(facilityName == "LOG_MAIL")
+   {
+      return LOG_MAIL;
+   }
+   else if(facilityName == "LOG_NEWS")
+   {
+      return LOG_NEWS;
+   }
+   else if(facilityName == "LOG_SYSLOG")
+   {
+      return LOG_SYSLOG;
+   }
+   else if(facilityName == "LOG_USER")
+   {
+      return LOG_USER;
+   }
+   else if(facilityName == "LOG_UUCP")
+   {
+      return LOG_UUCP;
+   }
+#endif
+   // Nothing matched or syslog not supported on this platform
+   return -1;
 }
 
 void 
 Log::initialize(Type type, Level level, const Data& appName, 
                 const char * logFileName,
-                ExternalLogger* externalLogger)
+                ExternalLogger* externalLogger,
+                const Data& syslogFacilityName)
 {
    Lock lock(_mutex);
    mDefaultLoggerData.reset();   
@@ -145,6 +247,22 @@ Log::initialize(Type type, Level level, const Data& appName,
    pb.skipBackToChar('/');
 #endif
    mAppName = pb.position();
+
+   if(!syslogFacilityName.empty())
+   {
+      mSyslogFacility = parseSyslogFacilityName(syslogFacilityName);
+      if(mSyslogFacility == -1)
+      {
+#ifndef WIN32
+         mSyslogFacility = LOG_DAEMON;
+         if(type == Log::Syslog)
+         {
+            syslog(LOG_DAEMON | LOG_ERR, "invalid syslog facility name specified (%s), falling back to LOG_DAEMON", syslogFacilityName.c_str());
+         }
+#endif
+         std::cerr << "invalid syslog facility name specified: " << syslogFacilityName.c_str() << std::endl;
+      }
+   }
  
    char buffer[1024];  
    gethostname(buffer, sizeof(buffer));
@@ -160,9 +278,10 @@ void
 Log::initialize(Type type,
                 Level level,
                 const Data& appName,
-                ExternalLogger& logger)
+                ExternalLogger& logger,
+                const Data& syslogFacilityName)
 {
-   initialize(type, level, appName, 0, &logger);
+   initialize(type, level, appName, 0, &logger, syslogFacilityName);
 }
 
 void
@@ -490,7 +609,7 @@ Log::getThreadSetting()
       Lock lock(_mutex);
       ThreadIf::Id thread = ThreadIf::selfId();
       HashMap<ThreadIf::Id, pair<ThreadSetting, bool> >::iterator res = Log::mThreadToLevel.find(thread);
-      assert(res != Log::mThreadToLevel.end());
+      resip_assert(res != Log::mThreadToLevel.end());
       if (res->second.second)
       {
          setting->mLevel = res->second.first.mLevel;
@@ -521,7 +640,7 @@ void
 Log::setThreadSetting(ThreadSetting info)
 {
 #ifndef LOG_ENABLE_THREAD_SETTING
-   assert(0);
+   resip_assert(0);
 #else
    //cerr << "Log::setThreadSetting: " << "service: " << info.service << " level " << toString(info.level) << " for " << pthread_self() << endl;
    ThreadIf::Id thread = ThreadIf::selfId();
@@ -547,7 +666,7 @@ Log::setServiceLevel(int service, Level l)
    Lock lock(_mutex);
    Log::mServiceToLevel[service] = l;
 #ifndef LOG_ENABLE_THREAD_SETTING
-   assert(0);
+   resip_assert(0);
 #else
    set<ThreadIf::Id>& threads = Log::mServiceToThreads[service];
    for (set<ThreadIf::Id>::iterator i = threads.begin(); i != threads.end(); i++)
@@ -722,7 +841,7 @@ void Log::LocalLoggerMap::decreaseUseCount(Log::LocalLoggerId loggerId)
    if (it != mLoggerInstancesMap.end())
    {
       it->second.second--;
-      assert(it->second.second >= 0);
+      resip_assert(it->second.second >= 0);
    }
 }
 
@@ -792,7 +911,12 @@ Log::Guard::~Guard()
    else 
    {
       // endl is magic in syslog -- so put it here
-      Instance((int)mData.size()+2) << mData << std::endl;  
+      std::ostream& _instance = Instance((int)mData.size()+2);
+      if (logType == resip::Log::Syslog)
+      {
+         _instance << mLevel;
+      }
+      _instance << mData << std::endl;  
    }
 }
 
@@ -805,8 +929,7 @@ Log::ThreadData::Instance(unsigned int bytesToWrite)
       case Log::Syslog:
          if (mLogger == 0)
          {
-            std::cerr << "Creating a syslog stream" << std::endl;
-            mLogger = new SysLogStream;
+            mLogger = new SysLogStream(mAppName, mSyslogFacility);
          }
          return *mLogger;
 
@@ -821,7 +944,6 @@ Log::ThreadData::Instance(unsigned int bytesToWrite)
              (maxLineCount() && mLineCount >= maxLineCount()) ||
              (maxByteCount() && ((unsigned int)mLogger->tellp()+bytesToWrite) >= maxByteCount()))
          {
-            std::cerr << "Creating a logger for file \"" << mLogFileName.c_str() << "\"" << std::endl;
             Data logFileName(mLogFileName != "" ? mLogFileName : "resiprocate.log");
             if (mLogger)
             {
@@ -838,7 +960,7 @@ Log::ThreadData::Instance(unsigned int bytesToWrite)
          mLineCount++;
          return *mLogger;
       default:
-         assert(0);
+         resip_assert(0);
          return std::cout;
    }
 }
