@@ -1,10 +1,7 @@
-#if !defined(WIN32)
-#include <syslog.h>
-#endif
-
 #include <cstdio>
-#include <cassert>
+#include "rutil/ResipAssert.h"
 #include "rutil/SysLogBuf.hxx"
+#include "rutil/Log.hxx"
 
 #ifndef EOF
 # define EOF (-1)
@@ -13,10 +10,32 @@
 using resip::SysLogBuf;
 
 SysLogBuf::SysLogBuf ()
+ : mLevel(Log::Debug),
+   mAppName(""),
+   mFacility(LOG_DAEMON)
+{
+   init();
+}
+
+SysLogBuf::SysLogBuf (const resip::Data& ident, int facility)
+ : mLevel(Log::Debug),
+   mAppName(ident),
+   mFacility(facility)
+{
+   init();
+}
+
+void
+SysLogBuf::init()
 {
 #if !defined(WIN32)
    setp(buffer,buffer+Size);
-   openlog (0, LOG_NDELAY | LOG_PID, LOG_LOCAL6);
+   const char* _ident = 0;
+   if(!mAppName.empty())
+   {
+      _ident = mAppName.c_str();
+   }
+   openlog (_ident, LOG_NDELAY | LOG_PID, mFacility);
 #endif
 }
       
@@ -28,11 +47,44 @@ int
 SysLogBuf::sync()
 {
 #if !defined(WIN32)
+   // Default to debug level for Stack, Debug and unrecognised values
+   int _level = LOG_DEBUG;
+   // For efficiency, we check mLevel in decreasing order of frequency,
+   // anticipating that Stack is the most common and Crit is the least
+   // common.
+   switch(mLevel)
+   {
+      case Log::Stack:
+      case Log::Debug:
+         // This is just here to avoid traversing the rest
+         // of the switch block for every Stack or Debug message.
+         // They will just be logged with the default LOG_DEBUG
+         // specified above.
+         break;
+      case Log::Info:
+         _level = LOG_INFO;
+         break;
+      case Log::Warning:
+         _level = LOG_WARNING;
+         break;
+      case Log::Err:
+         _level = LOG_ERR;
+         break;
+      case Log::Crit:
+         _level = LOG_CRIT;
+         break;
+      default:
+         // just let it use the default value defined above
+         break;
+   }
    *(pptr()) = 0;
-   syslog (LOG_LOCAL6 | LOG_DEBUG, "%s", pbase());
+   syslog (mFacility | _level, "%s", pbase());
+   // Set mLevel back to the default level for the next log entry
+   // in case it is not explicitly specified next time.
+   mLevel = Log::Debug;
    setp(buffer, buffer+Size);
 #else
-   assert(0);
+   resip_assert(0);
 #endif
    return 0;
 }
@@ -49,6 +101,16 @@ SysLogBuf::overflow (int c)
    return c;
 }
 
+std::ostream& resip::operator<< (std::ostream& os, const resip::Log::Level& level)
+{
+   // FIXME - we should probably find a more precise way to make sure
+   // that this can never be done for the wrong type of stream.
+   // For now, we rely on Log.cxx checking if mLogger is of type Syslog
+   // and not sending Level to the stream otherwise.
+   static_cast<SysLogBuf *>(os.rdbuf())->mLevel = level;
+   return os;
+}
+
 /* ====================================================================
  * The Vovida Software License, Version 1.0 
  * 
