@@ -83,7 +83,7 @@ class AresDnsPollItem : public FdPollItemBase
 void
 AresDnsPollItem::processPollEvent(FdPollEventMask mask)
 {
-   assert( (mask&(FPEM_Read|FPEM_Write))!= 0 );
+   resip_assert( (mask&(FPEM_Read|FPEM_Write))!= 0 );
 
    time_t nowSecs;
    time(&nowSecs);	/// maybe nice if this was passed into us?
@@ -110,31 +110,31 @@ AresDnsPollItem::socket_poll_cb(void *cb_data,
    AresDnsPollItem *olditem = ares->mPollItems.at(server_idx);
    if ( olditem )
    {
-      assert( olditem->mChannel==channel );
-      assert( olditem->mServerIdx==server_idx );
+      resip_assert( olditem->mChannel==channel );
+      resip_assert( olditem->mServerIdx==server_idx );
    }
    switch ( act )
    {
    case ARES_POLLACTION_OPEN:
-      assert( olditem==NULL );
-      assert( fd!=INVALID_SOCKET );
+      resip_assert( olditem==NULL );
+      resip_assert( fd!=INVALID_SOCKET );
       ares->mPollItems[server_idx] = new AresDnsPollItem( grp, fd, *ares, channel, server_idx);
       break;
    case ARES_POLLACTION_CLOSE:
-      assert( olditem );
+      resip_assert( olditem );
       ares->mPollItems[server_idx] = NULL;
       delete olditem;	// destructor removes from poll
       break;
    case ARES_POLLACTION_WRITEON:
-      assert( olditem );
+      resip_assert( olditem );
       grp->modPollItem(olditem->mPollHandle, FPEM_Read|FPEM_Write);
       break;
    case ARES_POLLACTION_WRITEOFF:
-      assert( olditem );
+      resip_assert( olditem );
       grp->modPollItem(olditem->mPollHandle, FPEM_Read);
       break;
    default:
-      assert( 0 );
+      resip_assert( 0 );
    }
 }
 
@@ -194,6 +194,18 @@ AresDns::init(const std::vector<GenericIPAddress>& additionalNameservers,
    if (ret != Success)
       return ret;
 
+#ifndef USE_CARES
+   if ( mPollGrp )
+   {
+      // Ensure vector starts empty, since init may be called more than once
+      mPollItems.clear(); 
+      // expand vector to hold {nservers} and init to NULLAr
+      mPollItems.insert( mPollItems.end(), mChannel->nservers, (AresDnsPollItem*)0);
+      // tell ares to let us know when things change
+      ares_process_set_poll_cb(mChannel, AresDnsPollItem::socket_poll_cb, this);
+   }
+#endif
+
 #ifdef WIN32
       // For windows OSs it is uncommon to run a local DNS server.  Therefor if there
       // are no defined DNS servers in windows networking and ARES just returned the
@@ -221,8 +233,7 @@ AresDns::internalInit(const std::vector<GenericIPAddress>& additionalNameservers
                       unsigned int features,
                       ares_channeldata** channel,
                       int timeout,
-                      int tries
-)
+                      int tries)
 {
    if(*channel)
    {
@@ -373,24 +384,14 @@ AresDns::internalInit(const std::vector<GenericIPAddress>& additionalNameservers
       // In ares, we must manipulate these directly
       if (timeout > 0)
       {
-         mChannel->timeout = timeout;
+         (*channel)->timeout = timeout;
       }
 
       if (tries > 0)
       {
-         mChannel->tries = tries;
+         (*channel)->tries = tries;
       }
 
-#ifndef USE_CARES
-      if ( mPollGrp )
-      {
-         // expand vector to hold {nservers} and init to NULL
-         mPollItems.insert( mPollItems.end(), (*channel)->nservers, (AresDnsPollItem*)0);
-         // tell ares to let us know when things change
-         ares_process_set_poll_cb(mChannel, AresDnsPollItem::socket_poll_cb, this);
-      }
-#endif
-
 #elif defined(USE_CARES)
       {
          // Log which version of c-ares we're using
@@ -543,7 +544,7 @@ AresDns::~AresDns()
 
 bool AresDns::hostFileLookup(const char* target, in_addr &addr)
 {
-   assert(target);
+   resip_assert(target);
 
    hostent *hostdata = 0;
 
@@ -626,7 +627,7 @@ AresDns::processTimers()
 #ifdef USE_CARES
    return;
 #else
-   assert( mPollGrp!=0 );
+   resip_assert( mPollGrp!=0 );
    time_t timeSecs;
    time(&timeSecs);
    ares_process_poll(mChannel, /*server*/-1, /*rd*/-1, /*wr*/-1, timeSecs);
