@@ -34,7 +34,7 @@ void
 CheckContacts::operator()(boost::shared_ptr<Event> event)
 {
    SipEvent* sipEvent = dynamic_cast<SipEvent*>(event.get());
-   assert(sipEvent);
+   resip_assert(sipEvent);
    boost::shared_ptr<SipMessage> msg = sipEvent->getMessage();
 
    set<NameAddr> msgContacts;
